@@ -9,7 +9,7 @@ from django.conf import settings
 
 from edc_constants.constants import CLOSED, OTHER
 from edc_form_validators.base_form_validator import INVALID_ERROR
-from edc_utils import convert_php_dateformat
+from edc_utils.text import convert_php_dateformat
 
 if TYPE_CHECKING:
     from datetime import date
