@@ -1,14 +1,14 @@
 from textwrap import fill
 
 import inflect
+from django.conf import settings
+from edc_constants.constants import OTHER, YES
+from edc_pdf_reports.crf_pdf_report import CrfPdfReport
 from reportlab.lib import colors
 from reportlab.lib.units import cm
 from reportlab.platypus import Paragraph, Table
 from reportlab.platypus.flowables import KeepTogether, Spacer
 
-from edc_constants.constants import OTHER, YES
-from edc_pdf_reports.crf_pdf_report import CrfPdfReport
-
 from ..utils import get_adverse_event_app_label, get_ae_model
 
 p = inflect.engine()
@@ -20,6 +20,7 @@ class AePdfReport(CrfPdfReport):
         f"{get_adverse_event_app_label()}_admin:{get_adverse_event_app_label()}_"
         "aeinitial_changelist"
     )
+    draw_logo = getattr(settings, "EDC_PDF_REPORTS_DRAW_LOGO", True)
 
     def get_report_story(self, **kwargs):
         story = []
