@@ -4,7 +4,7 @@ from django.dispatch import receiver
 from django.utils import timezone
 
 from edc_constants.constants import NO
-from edc_utils import formatted_datetime
+from edc_utils.text import formatted_datetime
 from edc_visit_schedule.site_visit_schedules import site_visit_schedules
 from edc_visit_tracking.utils import get_related_visit_model_cls
 
