@@ -8,6 +8,7 @@ ABNORMAL = "ABNORMAL"
 ABSENT = "absent"
 ADDITIONAL = True
 AFTERNOON = "afternoon"
+AGREE = "agree"
 ALIVE = "alive"
 ALWAYS = "always"
 ANONYMOUS = "anonymous"
@@ -40,6 +41,7 @@ DEFAULTER = "defaulter"
 DELETE = "DELETE"
 DELIVERY = "delivery"
 DIABETES = "diabetes"
+DISAGREE = "disagree"
 DIVORCED = "divorced"
 DM = "dm"
 DONE = "done"
@@ -109,6 +111,7 @@ MULTI_MORBIDITY = "multi"
 NAIVE = "NAIVE"
 NCD = "NCD"
 NEG = "NEG"
+NEUTRAL = "neutral"
 NEVER = "NEVER"
 NEW = "New"
 NEW_FIELD = "new_field"
@@ -192,6 +195,8 @@ SMOKER = "smoker"
 SOMETIMES = "sometimes"
 STEROIDS = "steroids"
 STOPPED = "stopped"
+STRONGLY_AGREE = "strongly_agree"
+STRONGLY_DISAGREE = "strongly_disagree"
 STUDY_DEFINED_TIMEPOINT = "study_defined_timepoint"
 SUBJECT = "subject"
 SYSTEMATIC = "systematic"
@@ -238,3 +243,8 @@ THURSDAY = "thursday"
 FRIDAY = "friday"
 SATURDAY = "saturday"
 SUNDAY = "sunday"
+
+VERY_DIFFICULT = "very_difficult"
+DIFFICULT = "difficult"
+EASY = "easy"
+VERY_EASY = "very_easy"
