@@ -31,8 +31,8 @@ class CrfNoManagerModelMixin(
 
     class Meta:
         abstract = True
-        indexes = [
+        indexes = (
             models.Index(fields=["subject_visit", "site"]),
             models.Index(fields=["subject_visit", "report_datetime"]),
-        ]
+        )
         default_permissions = ("add", "change", "delete", "view", "export", "import")
