@@ -1,4 +1,4 @@
-from typing import Any, Optional
+from typing import Any
 
 from django.db import models
 
@@ -17,7 +17,7 @@ class DocumentStatusModelMixin(models.Model):
 
     document_status_comments = models.TextField(
         verbose_name="Any comments related to status of this document",
-        null=True,
+        default="",
         blank=True,
         help_text="for example, why some data is still pending",
     )
@@ -26,9 +26,7 @@ class DocumentStatusModelMixin(models.Model):
         self.update_document_status_on_save(kwargs.get("update_fields"))
         super().save(*args, **kwargs)
 
-    def update_document_status_on_save(
-        self, update_fields: Optional[list] = None
-    ) -> None:
+    def update_document_status_on_save(self, update_fields: list | None = None) -> None:
         """Updates `document_status` as complete unless field is listed
         in update_fields.
 
