@@ -3,7 +3,7 @@ from django.db import models
 from django.db.models import Index, UniqueConstraint
 from django.utils.translation import gettext as _
 
-from edc_utils import convert_php_dateformat
+from edc_utils.text import convert_php_dateformat
 
 
 class Holiday(models.Model):
