@@ -3,7 +3,7 @@ from django.db import models
 from edc_reportable import MILLIMOLES_PER_LITER_DISPLAY
 from edc_reportable.units import MILLIGRAMS_PER_DECILITER, MILLIMOLES_PER_LITER
 
-from ..model_mixin_factory import reportable_result_model_mixin_factory
+from ..model_mixin_factories import reportable_result_model_mixin_factory
 
 
 class MagnesiumModelMixin(
