@@ -5,7 +5,7 @@ from django.core.exceptions import ObjectDoesNotExist
 
 from edc_constants.constants import NO, YES
 from edc_form_validators import FormValidator
-from edc_utils import convert_php_dateformat
+from edc_utils.text import convert_php_dateformat
 from edc_visit_tracking.constants import MISSED_VISIT
 from edc_visit_tracking.utils import get_related_visit_model_cls
 
