@@ -3,9 +3,7 @@ from django.db.models import expressions
 from simple_history import signals
 
 
-@dispatch.receiver(
-    signals.pre_create_historical_record, dispatch_uid="simple_history_refresh"
-)
+@dispatch.receiver(signals.pre_create_historical_record, dispatch_uid="simple_history_refresh")
 def remove_f_expressions(sender, instance, history_instance, **kwargs) -> None:
     """Model with history manager fails to save if update contains
     an F() expression.
@@ -18,7 +16,7 @@ def remove_f_expressions(sender, instance, history_instance, **kwargs) -> None:
     django-simple-history-by-overriding-save/62369328#62369328
     """
     f_expression_fields = []
-    for field in history_instance._meta.fields:  # noqa
+    for field in history_instance._meta.fields:
         field_value = getattr(history_instance, field.name)
         if isinstance(field_value, expressions.BaseExpression):
             f_expression_fields.append(field.name)
