@@ -5,7 +5,7 @@ from edc_randomization.blinding import user_is_blinded_from_request
 from .list_filters import AssignmentListFilter
 
 
-def remove_fields_for_blinded_users(request: WSGIRequest, fields: tuple) -> tuple:
+def remove_fields_for_blinded_users(request: WSGIRequest, fields: tuple) -> tuple[str, ...]:
     """You need to secure custom SimpleListFilters yourself"""
     if user_is_blinded_from_request(request):
         fields = list(fields)
