@@ -8,7 +8,6 @@ from django.utils.text import format_lazy
 from django.utils.translation import gettext_lazy as _
 
 from edc_consent import site_consents
-from edc_consent.consent_definition import ConsentDefinition
 from edc_crf.crf_form_validator_mixins import BaseFormValidatorMixin
 
 
@@ -19,17 +18,17 @@ class PrnFormValidatorMixin(BaseFormValidatorMixin):
 
     @property
     def subject_consent(self):
-        return self.get_consent_definition(
+        return site_consents.get_consent_definition(
             report_datetime=self.report_datetime
         ).model_cls.objects.get(subject_identifier=self.subject_identifier)
 
-    def get_consent_definition(
-        self,
-        report_datetime: datetime = None,
-        fldname: str = None,
-        error_code: str = None,
-    ) -> ConsentDefinition:
-        return site_consents.get_consent_definition(report_datetime=self.report_datetime)
+    # def get_consent_definition(
+    #     self,
+    #     report_datetime: datetime | None = None,
+    #     fldname: str | None = None,
+    #     error_code: str | None = None,
+    # ) -> ConsentDefinition:
+    #     return site_consents.get_consent_definition(report_datetime=self.report_datetime)
 
     @property
     def report_datetime(self) -> datetime:
