@@ -9,13 +9,13 @@ from .constants import (
 
 
 class ProtocolDeviationViolationAction(ActionWithNotification):
-    reference_model = None  # "my_app.protocolincident"
-    admin_site_name = None  # "my_app_admin"
+    reference_model = "edc_protocol_incident.protocoldeviationviolation"
+    admin_site_name = "edc_protocol_incident_admin"
 
     name = PROTOCOL_DEVIATION_VIOLATION_ACTION
     display_name = "Submit Protocol Deviation / Violation Report"
     notification_display_name = "Protocol Deviation / Violation Report"
-    parent_action_names = []
+    parent_action_names = ()
     show_link_to_changelist = True
     show_link_to_add = True
     priority = HIGH_PRIORITY
@@ -25,13 +25,13 @@ class ProtocolDeviationViolationAction(ActionWithNotification):
 
 
 class ProtocolIncidentAction(ActionWithNotification):
-    reference_model = None  # "my_app.protocolincident"
-    admin_site_name = None  # "my_app"
+    reference_model = "edc_protocol_incident.protocolincident"
+    admin_site_name = "edc_protocol_incident_admin"
 
     name = PROTOCOL_INCIDENT_ACTION
     display_name = "Submit Protocol Incident Report"
     notification_display_name = "Protocol Incident Report"
-    parent_action_names = []
+    parent_action_names = ()
     show_link_to_changelist = True
     show_link_to_add = True
     priority = HIGH_PRIORITY
