@@ -32,7 +32,7 @@ class NoteModelAdminMixin(
     """A modeladmin mixin class for the Note model."""
 
     form = NoteForm
-    ordering = ["site", "subject_identifier"]
+    ordering = ("site", "subject_identifier")
 
     note_template_name = "edc_qareports/qa_report_note.html"
 
@@ -52,41 +52,50 @@ class NoteModelAdminMixin(
         audit_fieldset_tuple,
     )
 
-    list_display = [
+    list_display = (
         "dashboard",
         "subject_identifier",
         "report",
         "status",
         "report_note",
         "report_datetime",
-    ]
+    )
 
-    radio_fields = {"status": admin.VERTICAL}
+    radio_fields = {"status": admin.VERTICAL}  # noqa: RUF012
 
-    list_filter = [
+    list_filter = (
         "report_datetime",
         "status",
         "report_model",
         "user_created",
         "user_modified",
-    ]
+    )
 
-    search_fields = ["subject_identifier", "name"]
+    search_fields = ("subject_identifier", "report_model")
 
-    @admin.display(description="Report", ordering="report_name")
+    @admin.display(description="Report", ordering="report_model")
     def report(self, obj=None):
-        app_label, model = obj.report_model_cls._meta.label_lower.split(".")
-        changelist_url = "_".join([app_label, model, "changelist"])
         try:
-            # assume admin site naming convention
-            url = reverse(f"{app_label}_admin:{changelist_url}")
-        except NoReverseMatch:
-            # TODO: find the admin site where this model is registered
-            url = "#"
-        return format_html(
-            '<a data-toggle="tooltip" title="go to report" href="{}?q={}">{}</a>',
-            *(url, obj.subject_identifier, obj.report_model_cls._meta.verbose_name),
-        )
+            app_label, model = obj.report_model_cls._meta.label_lower.split(".")
+        except (LookupError, ValueError):
+            pass
+        else:
+            changelist_url = "_".join([app_label, model, "changelist"])
+            try:
+                # assume admin site naming convention
+                url = reverse(f"{app_label}_admin:{changelist_url}")
+            except NoReverseMatch:
+                # TODO: find the admin site where this model is registered
+                pass
+            else:
+                return format_html(
+                    '<a data-toggle="tooltip" title="go to report" href='
+                    '"{url}?q={subject_identifier}">{report_model_cls}</a>',
+                    url=url,
+                    subject_identifier=obj.subject_identifier,
+                    report_model_cls=obj.report_model_cls._meta.verbose_name,
+                )
+        return obj.report_model
 
     @admin.display(description="QA Note", ordering="note")
     def report_note(self, obj=None):
