@@ -62,13 +62,9 @@ class QaReportModelAdminMixin:
         return tuple(list_filter)
 
     def get_note_model_obj_or_raise(self, obj=None):
-        try:
-            note_model_obj = self.note_model_cls.objects.get(
-                report_model=obj.report_model, subject_identifier=obj.subject_identifier
-            )
-        except ObjectDoesNotExist:
-            raise
-        return note_model_obj
+        return self.note_model_cls.objects.get(
+            report_model=obj.report_model, subject_identifier=obj.subject_identifier
+        )
 
     @admin.display(description="Status")
     def status(self, obj) -> str:
@@ -106,7 +102,7 @@ class QaReportModelAdminMixin:
         url = (
             f"{url}?next={next_url_name},subject_identifier,q"
             f"&subject_identifier={obj.subject_identifier}"
-            f"&report_model={obj.report_model}&q={obj.subject_identifier}"
+            f"&report_model={self.model._meta.label_lower}&q={obj.subject_identifier}"
         )
         label = self.get_notes_label(note_model_obj)
         context = dict(title=title, url=url, label=label)
