@@ -1,8 +1,4 @@
-import os
-from warnings import warn
-
 from django.apps import AppConfig as DjangoAppConfig
-from django.conf import settings
 from django.core.checks.registry import register
 
 from .system_checks import randomizationlist_check
@@ -17,10 +13,11 @@ class AppConfig(DjangoAppConfig):
     def ready(self):
         register(randomizationlist_check, deploy=True)
 
-    @property
-    def randomization_list_path(self):
-        warn(
-            "Use of settings.RANDOMIZATION_LIST_PATH has been deprecated. "
-            "See site_randomizers in edc_randomization"
-        )
-        return os.path.join(settings.RANDOMIZATION_LIST_PATH)
+    # @property
+    # def randomization_list_path(self):
+    #     warn(
+    #         "Use of settings.RANDOMIZATION_LIST_PATH has been deprecated. "
+    #         "See site_randomizers in edc_randomization",
+    #         stacklevel=2,
+    #     )
+    #     return os.path.join(settings.RANDOMIZATION_LIST_PATH)
