@@ -14,14 +14,12 @@ style = color_style()
 
 
 def load_mw():
-    model_cls: MolecularWeight = django_apps.get_model(
-        "edc_reportable", "MolecularWeight"
-    )
+    model_cls: MolecularWeight = django_apps.get_model("edc_reportable", "MolecularWeight")
     for label, mw in molecular_weights.items():
         model_cls.objects.get_or_create(label=label, mw=mw)
 
 
-def post_migrate_load_reference_ranges(sender=None, **kwargs):  # noqa
+def post_migrate_load_reference_ranges(sender=None, **kwargs):
     sys.stdout.write(style.MIGRATE_HEADING("Loading reference ranges (reportables):\n"))
     load_mw()
     load_all_reference_ranges()
