@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Type
+from typing import TYPE_CHECKING
 
 from django.apps import apps as django_apps
 
@@ -11,5 +11,5 @@ if TYPE_CHECKING:
 __all__ = ["normal_data_model_cls"]
 
 
-def normal_data_model_cls() -> Type[NormalData]:
+def normal_data_model_cls() -> type[NormalData]:
     return django_apps.get_model("edc_reportable.normaldata")
