@@ -2,7 +2,7 @@ from edc_constants.constants import FEMALE, MALE
 
 
 class GenderEvaluator:
-    eligible_gender = [MALE, FEMALE]
+    eligible_gender = (MALE, FEMALE)
 
     def __init__(self, gender=None, **kwargs) -> None:  # noqa
         self.eligible = False
