@@ -4,6 +4,8 @@ import sys
 from django.conf import settings
 from django.core.management.base import BaseCommand
 from django.core.management.color import color_style
+from multisite.models import Alias
+from multisite.utils import create_or_sync_canonical_from_all_sites
 
 from edc_sites.site import sites as site_sites
 from edc_sites.utils import add_or_update_django_sites
@@ -15,7 +17,6 @@ class Command(BaseCommand):
     help = "Add / Update django Site model after changes to edc_sites"
 
     def add_arguments(self, parser):
-
         parser.add_argument(
             "--ping-hosts",
             default=False,
@@ -32,26 +33,19 @@ class Command(BaseCommand):
             help="Suggest ALLOWED_HOSTS",
         )
 
-    def handle(self, *args, **options) -> None:
+    def handle(self, *args, **options) -> None:  # noqa: ARG002
         sys.stdout.write("\n\n")
         sys.stdout.write(" Edc Sites : Adding / Updating sites ...     \n")
         add_or_update_django_sites(verbose=True)
-        if (
-            "multisite" in settings.INSTALLED_APPS
-            or "multisite.apps.AppConfig" in settings.INSTALLED_APPS
-        ):
-            from multisite.models import Alias
-            from multisite.utils import create_or_sync_canonical_from_all_sites
+        sys.stdout.write("\n Multisite. \n")
+        create_or_sync_canonical_from_all_sites(verbose=True)
 
-            sys.stdout.write("\n Multisite. \n")
-            create_or_sync_canonical_from_all_sites(verbose=True)
-
-            sys.stdout.write("    multisite.Alias \n")
-            for obj in Alias.objects.all():
-                sys.stdout.write(
-                    f"      - Site model: {obj.site.id}: {obj.domain} "
-                    f"is_canonical={obj.is_canonical}.\n"
-                )
+        sys.stdout.write("    multisite.Alias \n")
+        for obj in Alias.objects.all():
+            sys.stdout.write(
+                f"      - Site model: {obj.site.id}: {obj.domain} "
+                f"is_canonical={obj.is_canonical}.\n"
+            )
         arg = [arg for arg in sys.argv if arg.startswith("--settings")]
         sys.stdout.write(f"\n Settings: reading from {arg}")
         sys.stdout.write("\n\n Current value of settings.ALLOWED_HOSTS\n")
