@@ -8,10 +8,9 @@ class DashboardMiddleware:
         self.get_response = get_response
 
     def __call__(self, request):
-        response = self.get_response(request)
-        return response
+        return self.get_response(request)
 
-    def process_view(self, request, *args):
+    def process_view(self, request, *args):  # noqa: ARG002
         """Adds/Updates references to templates."""
         try:
             template_data = settings.SUBJECT_DASHBOARD_BASE_TEMPLATES
