@@ -19,5 +19,4 @@ class SubjectTransferAction(ActionWithNotification):
     singleton = True
 
     def get_next_actions(self):
-        next_actions = [END_OF_STUDY_ACTION]
-        return next_actions
+        return [END_OF_STUDY_ACTION]
