@@ -8,7 +8,7 @@ from edc_constants.choices import YES_NO, YES_NO_UNSURE
 from edc_identifier.model_mixins import UniqueSubjectIdentifierFieldMixin
 from edc_model import models as edc_models
 from edc_sites.model_mixins import SiteModelMixin
-from edc_utils import convert_php_dateformat
+from edc_utils.text import convert_php_dateformat
 
 from .choices import TRANSFER_INITIATORS
 from .constants import SUBJECT_TRANSFER_ACTION
