@@ -4,8 +4,6 @@ from datetime import datetime
 
 from django import forms
 
-from edc_utils import to_utc
-
 from ..subject_schedule import InvalidOffscheduleDate
 from .visit_schedule_non_crf_modelform_mixin import VisitScheduleNonCrfModelFormMixin
 
@@ -28,7 +26,7 @@ class OffScheduleModelFormMixin(VisitScheduleNonCrfModelFormMixin):
                     update=False,
                 )
             except InvalidOffscheduleDate as e:
-                raise forms.ValidationError(e)
+                raise forms.ValidationError(e) from e
             self.validate_visit_tracking_reports()
         return cleaned_data
 
@@ -42,7 +40,7 @@ class OffScheduleModelFormMixin(VisitScheduleNonCrfModelFormMixin):
     @property
     def offschedule_datetime(self) -> datetime | None:
         if self.offschedule_datetime_field_attr in self.cleaned_data:
-            return to_utc(self.cleaned_data.get(self.offschedule_datetime_field_attr))
+            return self.cleaned_data.get(self.offschedule_datetime_field_attr)
         return getattr(self.instance, self.offschedule_datetime_field_attr)
 
     @property
@@ -50,11 +48,11 @@ class OffScheduleModelFormMixin(VisitScheduleNonCrfModelFormMixin):
         return True
 
     class Meta:
-        help_text = {
+        help_text = {  # noqa: RUF012
             "subject_identifier": "(read-only)",
             "action_identifier": "(read-only)",
         }
-        widgets = {
+        widgets = {  # noqa: RUF012
             "subject_identifier": forms.TextInput(attrs={"readonly": "readonly"}),
             "action_identifier": forms.TextInput(attrs={"readonly": "readonly"}),
         }
