@@ -15,8 +15,8 @@ from edc_consent.exceptions import ConsentDefinitionError
 from edc_consent.site_consents import site_consents
 from edc_sites.site import sites as site_sites
 from edc_sites.utils import valid_site_for_subject_or_raise
-from edc_utils import convert_php_dateformat, formatted_datetime
 from edc_utils.date import to_local
+from edc_utils.text import convert_php_dateformat, formatted_datetime
 
 from .constants import OFF_SCHEDULE, ON_SCHEDULE
 from .exceptions import (
@@ -237,13 +237,13 @@ class SubjectSchedule:
                 schedule_name=self.schedule_name,
                 visit_schedule_name=self.visit_schedule_name,
             )
-        except ObjectDoesNotExist:
+        except ObjectDoesNotExist as e:
             raise NotOnScheduleError(
                 "Failed to take subject off schedule. "
                 f"Subject has not been put on schedule "
                 f"'{self.visit_schedule_name}.{self.schedule_name}'. "
                 f"Got '{self.subject_identifier}'."
-            )
+            ) from e
 
         if history_obj:
             self.update_history_or_raise(
@@ -293,7 +293,7 @@ class SubjectSchedule:
                 subject_identifier=self.subject_identifier,
                 schedule_name=self.schedule_name,
                 visit_schedule_name=self.visit_schedule_name,
-                **{f"{related_visit_model_attr}__report_datetime__gt": (offschedule_datetime)},
+                **{f"{related_visit_model_attr}__report_datetime__gt": offschedule_datetime},
             )
         except ObjectDoesNotExist:
             appointments = None
@@ -302,7 +302,7 @@ class SubjectSchedule:
                 subject_identifier=self.subject_identifier,
                 schedule_name=self.schedule_name,
                 visit_schedule_name=self.visit_schedule_name,
-                **{f"{related_visit_model_attr}__report_datetime__gt": (offschedule_datetime)},
+                **{f"{related_visit_model_attr}__report_datetime__gt": offschedule_datetime},
             )
         if appointments:
             raise InvalidOffscheduleDate(
@@ -336,12 +336,12 @@ class SubjectSchedule:
         model_cls = django_apps.get_model(self.registered_subject_model)
         try:
             obj = model_cls.objects.get(subject_identifier=self.subject_identifier)
-        except ObjectDoesNotExist:
+        except ObjectDoesNotExist as e:
             raise UnknownSubjectError(
                 f"Failed to put subject on schedule. Unknown subject. "
                 f"Searched `{self.registered_subject_model}`. "
                 f"Got subject_identifier=`{self.subject_identifier}`."
-            )
+            ) from e
         return obj
 
     @property
@@ -350,11 +350,11 @@ class SubjectSchedule:
             onschedule_obj = self.onschedule_model_cls.objects.get(
                 subject_identifier=self.subject_identifier
             )
-        except ObjectDoesNotExist:
+        except ObjectDoesNotExist as e:
             raise NotOnScheduleError(
                 f"Subject has not been put on a schedule `{self.schedule_name}`. "
                 f"Got subject_identifier=`{self.subject_identifier}`."
-            )
+            ) from e
         return onschedule_obj
 
     def onschedule_or_raise(self, report_datetime=None, compare_as_datetimes=None):
