@@ -3,10 +3,10 @@ from edc_form_validators import FormValidator
 
 
 class VisitMissedFormValidator(FormValidator):
+    min_contact_attempts_count = 3
+
     def clean(self) -> None:
-        self.applicable_if(
-            YES, field="contact_attempted", field_applicable="contact_made"
-        )
+        self.applicable_if(YES, field="contact_attempted", field_applicable="contact_made")
         self.required_if(
             YES,
             field="contact_attempted",
@@ -19,7 +19,8 @@ class VisitMissedFormValidator(FormValidator):
             else self.cleaned_data.get("contact_attempts_count")
         )
         cond = (
-            self.cleaned_data.get("contact_made") == NO and contact_attempts_count < 3
+            self.cleaned_data.get("contact_made") == NO
+            and contact_attempts_count < self.min_contact_attempts_count
         )
         self.required_if_true(
             cond,
@@ -39,6 +40,4 @@ class VisitMissedFormValidator(FormValidator):
             m2m_field="missed_reasons",
             field_other="missed_reasons_other",
         )
-        self.applicable_if(
-            ALIVE, UNKNOWN, field="survival_status", field_applicable="ltfu"
-        )
+        self.applicable_if(ALIVE, UNKNOWN, field="survival_status", field_applicable="ltfu")
